@@ -8,7 +8,7 @@ function ctrl_c() {
 rm -rf ./flask_regiment
 cp -r ../flask_regiment flask_regiment
 
-sed -i -e 's/protocol = "https"/protocol = "http"/; s/domain = "ingest.regiment.tech"/domain = "localhost:5002"/' ./flask_regiment/instalog.py;
+sed -i -e 's/protocol = "https"/protocol = "http"/; s/domain = "ingest.regiment.tech"/domain = "localhost:5002"/' ./flask_regiment/bulletlog.py;
 
 FLASK_APP=simple_server FLASK_RUN_PORT=5001 flask run
 
