@@ -1,34 +1,34 @@
 import os
 from flask import Flask
-from flask_regiment import InstaLog
+from flask_regiment import BulletLog
 from dotenv import load_dotenv
 load_dotenv()
 from simple_blueprint import bp
 
-instalog = InstaLog()
-print("instalog: loaded")
+bulletlog = BulletLog()
+print("bulletlog: loaded")
 
 def create_app(test_config=None):
     print("create_app called")
     # create and configure the app
     app = Flask(__name__, instance_relative_config=True)
     app.config.from_mapping(
-        INSTALOG_API_KEY=os.getenv('API_KEY'),
-        INSTALOG_API_SECRET_KEY=os.getenv('API_SECRET_KEY'),
-        INSTALOG_META_DATA={
+        BULLETLOG_API_KEY=os.getenv('API_KEY'),
+        BULLETLOG_API_SECRET_KEY=os.getenv('API_SECRET_KEY'),
+        BULLETLOG_META_DATA={
             "environment": "staging",
             "service_name": "test_app",
             "namespace": "zeroone"
         },
-        INSTALOG_LOG_TYPE='string'
+        BULLETLOG_LOG_TYPE='string'
     )
-    print("instalog: initialized")
+    print("bulletlog: initialized")
 
-    instalog.init_app(app)
-    print("instalog: registered")
+    bulletlog.init_app(app)
+    print("bulletlog: registered")
 
-    app.instalog.log_info("custom log from flask")
-    print("instalog: custom log sent")
+    app.bulletlog.log_info("custom log from flask")
+    print("bulletlog: custom log sent")
 
     app.register_blueprint(bp, url_prefix='/bp')
 
